//
// C++ Interface: kmfmainwindow
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2003
//
// Copyright: See COPYING file that comes with this distribution
//
//
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef KMFMAINWINDOW_H
#define KMFMAINWINDOW_H

#include <kparts/mainwindow.h>
#include "../core/kmyfirewallinterface.h"
#include "../core/netfilterobject.h"

/**
@author Christian Hubinger
*/

namespace KMF {
class KDE_EXPORT KMFMainWindow : public KParts::MainWindow, virtual public KMyFirewallInterface {
	Q_OBJECT
public:

	KMFMainWindow( QWidget* parent, const char *name );
	virtual ~KMFMainWindow();
signals:
	void sigUpdateView();
	void sigUpdateView( NetfilterObject*);
	void sigEnableActions( bool );
};
}
#endif
